@@ -24,7 +24,7 @@ from django.http import (
 )
 from django.test import SimpleTestCase
 from django.utils.functional import lazystr
-from django.utils.http import MAX_URL_LENGTH
+from django.utils.http import MAX_URL_REDIRECT_LENGTH
 
 
 class QueryDictTests(SimpleTestCase):
@@ -321,8 +321,8 @@ class HttpResponseTests(SimpleTestCase):
         self.assertEqual(r.headers["key"], "=?utf-8?b?4oCg?=")
         self.assertIn(b"=?utf-8?b?4oCg?=", r.serialize_headers())
 
-        # The response also converts string or bytes keys to strings, but requires
-        # them to contain ASCII
+        # The response also converts string or bytes keys to strings, but
+        # requires them to contain ASCII
         r = HttpResponse()
         del r.headers["Content-Type"]
         r.headers["foo"] = "bar"
@@ -351,8 +351,8 @@ class HttpResponseTests(SimpleTestCase):
         f = b"zzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzz a\xcc\x88"
         f = f.decode("utf-8")
         h.headers["Content-Disposition"] = 'attachment; filename="%s"' % f
-        # This one is triggering https://bugs.python.org/issue20747, that is Python
-        # will itself insert a newline in the header
+        # This one is triggering https://bugs.python.org/issue20747, that is
+        # Python will itself insert a newline in the header
         h.headers["Content-Disposition"] = (
             'attachment; filename="EdelRot_Blu\u0308te (3)-0.JPG"'
         )
@@ -486,12 +486,25 @@ class HttpResponseTests(SimpleTestCase):
         r.writelines(["foo\n", "bar\n", "baz\n"])
         self.assertEqual(r.content, b"foo\nbar\nbaz\n")
 
+    def test_redirect_url_max_length(self):
+        base_url = "https://example.com/"
+        for length in (
+            MAX_URL_REDIRECT_LENGTH - 1,
+            MAX_URL_REDIRECT_LENGTH,
+        ):
+            long_url = base_url + "x" * (length - len(base_url))
+            with self.subTest(length=length):
+                response = HttpResponseRedirect(long_url)
+                self.assertEqual(response.url, long_url)
+                response = HttpResponsePermanentRedirect(long_url)
+                self.assertEqual(response.url, long_url)
+
     def test_unsafe_redirect(self):
         bad_urls = [
             'data:text/html,<script>window.alert("xss")</script>',
             "mailto:test@example.com",
             "file:///etc/passwd",
-            "é" * (MAX_URL_LENGTH + 1),
+            "é" * (MAX_URL_REDIRECT_LENGTH + 1),
         ]
         for url in bad_urls:
             with self.assertRaises(DisallowedRedirect):
